@@ -6,6 +6,7 @@ import requests
 from tabulate import tabulate
 
 from luscious_dl.downloader import Downloader
+from luscious_dl.exceptions import NoAlbumInformation
 from luscious_dl.logger import logger
 from luscious_dl.querys import album_info_query, album_list_pictures_query, album_search_query
 
@@ -20,7 +21,7 @@ class Album:
     self.number_of_pictures = number_of_pictures
     self.number_of_animated_pictures = number_of_animated_pictures
     self.info = {}
-    self.pictures = []
+    self.pictures: list[str] = []
 
   def show(self) -> None:
     """Show album information."""
@@ -33,10 +34,9 @@ class Album:
     ]
     logger.log(5, f'Album information:\n{tabulate(table, tablefmt="jira")}')
 
-  def fetch_info(self) -> bool:
+  def fetch_info(self) -> None:
     """
     Fetch album information.
-    :return: bool - true if there are no error otherwise false
     """
     logger.log(5, 'Fetching album information...')
     response = requests.post('https://members.luscious.net/graphql/nobatch/?operationName=AlbumGet',
@@ -45,7 +45,7 @@ class Album:
     if 'errors' in data:
       logger.error(f'Something wrong with album: {self.id_}\nErrors: {data["errors"]}')
       logger.warning('Skipping...')
-      return False
+      raise NoAlbumInformation(self.id_, data.get('errors', None))
     self.title = data['title']
     self.author = data['created_by']['display_name']
     self.number_of_pictures = data['number_of_pictures']
@@ -53,11 +53,10 @@ class Album:
     self.info.update({
       'slug': data.get('slug', self.title),
       'language': data.get('language', {}).get('title', ''),
-      'tags':  [tag.get('text', '') for tag in data.get('tags', {})],
-      'genres':  [genre.get('title', '') for genre in data.get('genres', {})],
-      'audiences':  [audience.get('title', '') for audience in data.get('audiences', {})],
+      'tags': [tag.get('text', '') for tag in data.get('tags', {})],
+      'genres': [genre.get('title', '') for genre in data.get('genres', {})],
+      'audiences': [audience.get('title', '') for audience in data.get('audiences', {})],
     })
-    return True
 
   def fetch_pictures(self) -> None:
     """Fetch album pictures."""
@@ -122,9 +121,10 @@ def search_albums(search_query: str, sorting: str = 'date_trending', page: int =
                              json=album_search_query(search_query, sorting, page)).json()
     data = response['data']['album']['list']
     page += 1
-    for item in data['items']:
-      albums.append(Album(item['id'], item['title'], item['created_by']['display_name'],
-                          item['number_of_pictures'], item['number_of_animated_pictures']))
+    albums.extend(
+        Album(item['id'], item['title'], item['created_by']['display_name'],
+              item['number_of_pictures'], item['number_of_animated_pictures'])
+        for item in data['items'])
     if not data['info']['has_next_page'] or data['info']['page'] == max_pages:
       break
   return albums
@@ -136,12 +136,13 @@ def print_search(results: list[Album]) -> None:
   :param results: Album list
   """
   table = [
-    [album.id_,
-     album.title,
-     album.number_of_pictures,
-     album.number_of_animated_pictures,
-     album.author
-     ] for album in results
+    [
+      album.id_,
+      album.title,
+      album.number_of_pictures,
+      album.number_of_animated_pictures,
+      album.author
+    ] for album in results
   ]
   headers = ('ID', 'Title', 'Pictures', 'Gifs', 'Author')
   logger.log(5, f'Search Result Total: {len(results)}\n{tabulate(table, headers)}')
