@@ -5,6 +5,7 @@ from pathlib import Path
 from luscious_dl.album import Album, search_albums, print_search
 from luscious_dl.command_line import command_line
 from luscious_dl.downloader import Downloader
+from luscious_dl.exceptions import NoAlbumInformation, NoUserInformation
 from luscious_dl.logger import logger
 from luscious_dl.parser import extract_ids_from_list, extract_album_id, extract_user_id
 from luscious_dl.user import User
@@ -13,7 +14,7 @@ from luscious_dl.utils import info, format_foldername, generate_pdf, inputs_stri
 
 
 def albums_download(albums_ids: list[int], downloader: Downloader, output_dir: Path,
-                    foldername_format='%t', gen_pdf=False, gen_cbz=False, rm_origin_dir=False) -> None:
+                    foldername_format='[%i]%t', gen_pdf=False, gen_cbz=False, rm_origin_dir=False) -> None:
   """
   Start albums download process.
   :param albums_ids: list of album ids
@@ -27,26 +28,26 @@ def albums_download(albums_ids: list[int], downloader: Downloader, output_dir: P
   for id_ in albums_ids:
     album = Album(id_)
     try:
-      if album.fetch_info():
-        formmatted_foldername = format_foldername(album, foldername_format)
-        album_folder = Path.joinpath(output_dir, formmatted_foldername)
-        album.show()
-        album.fetch_pictures()
-        # album.generate_metadata(album_folder)
-        album.download(downloader, album_folder)
-        if gen_pdf:
-          generate_pdf(output_dir, formmatted_foldername, album_folder)
-        if gen_cbz:
-          generate_cbz(output_dir, formmatted_foldername, album_folder)
-        if rm_origin_dir:
-          delete_folder(album_folder, formmatted_foldername)
-      else:
-        raise Exception('Album Information not found.')
+      album.fetch_info()
+      formmatted_foldername = format_foldername(album, foldername_format)
+      album_folder = Path.joinpath(output_dir, formmatted_foldername)
+      album.show()
+      album.fetch_pictures()
+      # album.generate_metadata(album_folder)
+      album.download(downloader, album_folder)
+      if gen_pdf:
+        generate_pdf(output_dir, formmatted_foldername, album_folder)
+      if gen_cbz:
+        generate_cbz(output_dir, formmatted_foldername, album_folder)
+      if rm_origin_dir:
+        delete_folder(album_folder, formmatted_foldername)
+    except NoAlbumInformation as e:
+      logger.critical(f'Album: {id_} Error: {e.message}')
     except Exception as e:
-      logger.critical(f'Album: {id_} Error: {e}')
+      logger.critical(f'Album: {id_} Error: {e}  | {e.__class__.__name__}')
 
 
-def users_download(users_ids: list[int], downloader: Downloader, output_dir: Path, foldername_format='%t',
+def users_download(users_ids: list[int], downloader: Downloader, output_dir: Path, foldername_format='[%i]%t',
                    only_favorites=False, gen_pdf=False, gen_cbz=False, rm_origin_dir=False, group_by_user=False) -> \
         None:
   """
@@ -64,16 +65,16 @@ def users_download(users_ids: list[int], downloader: Downloader, output_dir: Pat
   for id_ in users_ids:
     user = User(id_)
     try:
-      if user.fetch_info():
-        user.fetch_albums(only_favorites)
-        user.show()
-        if group_by_user:
-          output_dir = output_dir.joinpath(os.path.normcase(user.name))
-        albums_download(user.albums_ids, downloader, output_dir, foldername_format, gen_pdf, gen_cbz, rm_origin_dir)
-      else:
-        raise Exception('User Information not found.')
+      user.fetch_info()
+      user.fetch_albums(only_favorites)
+      user.show()
+      if group_by_user:
+        output_dir = output_dir.joinpath(os.path.normcase(user.name))
+      albums_download(user.albums_ids, downloader, output_dir, foldername_format, gen_pdf, gen_cbz, rm_origin_dir)
+    except NoUserInformation as e:
+      logger.critical(f'User: {id_} Error: {e.message}')
     except Exception as e:
-      logger.critical(f'User: {id_} Error: {e}')
+      logger.critical(f'User: {id_} Error: {e} | {e.__class__.__name__}')
 
 
 def normalize_args(args: Namespace) -> Namespace:
@@ -100,20 +101,20 @@ def normalize_args(args: Namespace) -> Namespace:
     args.album_inputs = ','.join(list_data)
 
   if args.only_favorites and not args.user_inputs:
-    logger.warn(f"You're passing --favorites/-f flag without any user input.")
+    logger.warn("You're passing --favorites/-f flag without any user input.")
     args.only_favorites = False
 
   if args.gen_pdf and not args.album_inputs and not args.user_inputs and not args.search_download:
-    logger.warn(f"You're passing --pdf flag without any album/user input or search download.")
+    logger.warn("You're passing --pdf flag without any album/user input or search download.")
     args.gen_pdf = False
 
   if args.gen_cbz and not args.album_inputs and not args.user_inputs and not args.search_download:
-    logger.warn(f"You're passing --cbz flag without any album/user input or search download.")
+    logger.warn("You're passing --cbz flag without any album/user input or search download.")
     args.gen_cbz = False
 
   if args.rm_origin_dir and not args.gen_pdf and not args.gen_cbz:
-    logger.warn(f"You're passing --rm-origin-dir flag without any pdf or cbz generation. This would delete the album "
-                f"after download")
+    logger.warn("You're passing --rm-origin-dir flag without any pdf or cbz generation. This would delete the album "
+                "after download")
     args.rm_origin_dir = False
 
   args.keyword = args.keyword.strip() if args.keyword else None
